//
// Real Time Linux Example of a oscilloscope Widget
//
//
//

#ifndef SCOPE_H
#define SCOPE_H


#include "das1600.h"

#include <stdio.h>
#include <fcntl.h>
#include <sys/time.h>
#include <sys/types.h>
#include <unistd.h>

#include <qtimer.h>
#include <qframe.h>
#include <qcombo.h>
#include <qevent.h>
#include <qpushbt.h>



class ScopeTimer : public QTimer
{
    Q_OBJECT
public:
    ScopeTimer( QWidget *parent );
    enum { MAXSPEED = 1000 };

public slots:
    void        pause( bool );

private:
    int         interval;
};





class ScopeCanvas : public QFrame
{
    Q_OBJECT
public:
    ScopeCanvas( QWidget *parent = 0, const char *name = 0 );

    void        setPoint( int i, int j );

    int         maxCol() { return maxi; }
    int         maxRow() { return maxj; }
    int         holdDisplay;
    void        voltage(int);
    void        timediv(int);
    double      voltage_scale;
    int         time_scale;
    int         center_scale;
    int         ad0; /* fifo for real time data */
    int         x;
public slots:
    void	showSignal();
    void        set_voltage_scale(int);
    void        set_time_scale(int);
    void        hold();
private slots:
    void        clear();


protected:
    void	timerEvent( );

private:
    enum { SCALE = 10, MAXSIZE = 50, MINSIZE = 10, BORDER = 5 };

    bool        cells[2][MAXSIZE + 2][MAXSIZE + 2];
    ScopeTimer  *timer;
    int		normalTimer;
    int         current;
    int         maxi, maxj;
    int         y, oldx, oldy;
    char        inbyte[2];
    static int  pos2index( int x )
    {
        return ( x - BORDER ) / SCALE + 1;
    }
    static int index2pos( int i )
    {
        return  ( i - 1 ) * SCALE + BORDER;
    }

};




class Scope : public QFrame		
{
    Q_OBJECT
public:
    Scope( QWidget *parent=0, const char *name=0 );
    int time_scale;

    int         ad0; /* fifo for real time data */
protected:					// event handlers

private slots:					// internal slots

private:					// internal data
    enum { TOPBORDER = 70, SIDEBORDER = 10 };
    QPushButton  *pb;
    void	showDate();
    ScopeCanvas *scope;
    bool	showingColon;
    int         x,y,oldx,oldy;
//    unsigned char inbyte;
};




#endif // SCOPE_H
